﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Shared.Events;
using System.Diagnostics;
using Infragistics.UltraChart.Core.Primitives;

namespace CompositeChart
{
    public partial class Form1 : Form
    {
        private NumericSeries series1;
        private NumericSeries series2;
        private NumericSeries series3;
        private NumericSeries series4;
        private NumericSeries series5;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraChart1.ChartType = ChartType.Composite;

            ChartArea area = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(area);

            AxisItem axis1 = new AxisItem();
            axis1.Extent = 20;
            axis1.DataType = AxisDataType.Numeric;
            axis1.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axis1.OrientationType = AxisNumber.Y_Axis;

            axis1.RangeType = AxisRangeType.Custom;
            axis1.RangeMin = -10;
            axis1.RangeMax = 100;
            axis1.TickmarkInterval = 20;
            axis1.TickmarkStyle = AxisTickStyle.DataInterval;
            area.Axes.Add(axis1);

            AxisItem axisX = new AxisItem();
            axisX.DataType = AxisDataType.String;
            axisX.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            area.Axes.Add(axisX);


            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.LineChart;
            myColumnLayer.ChartArea = area;


            DataTable dt = new DataTable();
            dt.Columns.Add("Month");
            dt.Columns.Add("2007");
            dt.Columns.Add("2008");
            dt.Columns.Add("2009");
            dt.Columns.Add("2010");
            dt.Columns.Add("2011");

            dt.Rows.Add("Jan", 35, 10, 40, 30, 45);
            dt.Rows.Add("Fab", 2, 15, 55, 35, 80);
            dt.Rows.Add("Mar", 5, 35, 25, 50, 90);
            dt.Rows.Add("Apr", 2, 60, 35, 70, 80);
            dt.Rows.Add("May", 7, 55, 45, 80, 35);
            dt.Rows.Add("Jun", 85, 45, 40, 75, 30);



            series1 = new NumericSeries();
            series1.DataBind(dt, "2007", "Month");
            series1.PEs.Add(new PaintElement(Color.Red));
            series1.Label = "Year 2007";
            ultraChart1.Tooltips.FormatString = "<SERIES_LABEL:MMM yyyy>" + Environment.NewLine + "<ITEM_LABEL>: <DATA_VALUE:00.##>";
            myColumnLayer.Series.Add(series1);
            ultraChart1.CompositeChart.Series.Add(series1);

            ultraTree1.Nodes.Add("S1", "Series 2007");
            ultraTree1.Nodes["S1"].CheckedState = CheckState.Checked;


            LineAppearance la = new LineAppearance(ultraChart1);
            la.IconAppearance.Icon = SymbolIcon.Circle;
            la.IconAppearance.IconSize = SymbolIconSize.Medium;// Large;
            la.LineStyle.EndStyle = LineCapStyle.DiamondAnchor;
            la.Thickness = 5;
          
            
            
            LineChartAppearance lca = new LineChartAppearance();
            lca.LineAppearances.Add(la);
            myColumnLayer.ChartTypeAppearance = lca;

            ChartTextAppearance cta = new ChartTextAppearance();
            cta.Row = -2;
            cta.Column = -2;
            cta.ItemFormatString = axis1.Labels.ItemFormatString;
            cta.ClipText = true;
            cta.VerticalAlign = StringAlignment.Far;
            cta.ChartTextFont = new Font("Ariel", 18.2F, GraphicsUnit.Pixel);
            cta.ClipText = true;
            cta.Visible = true;
            lca.ChartText.Add(cta);
            


            series2 = new NumericSeries();
            series2.DataBind(dt, "2008", "Month");
            series2.Label = "Year 2008";
            series2.PEs.Add(new PaintElement(Color.Blue));
            myColumnLayer.Series.Add(series2);
            ultraChart1.CompositeChart.Series.Add(series2);
            ultraTree1.Nodes.Add("S2", "Series 2008");
            ultraTree1.Nodes["S2"].CheckedState = CheckState.Checked;

            series3 = new NumericSeries();
            series3.DataBind(dt, "2009", "Month");
            series3.Label = "Year 2009";
            series3.PEs.Add(new PaintElement(Color.Yellow));
            myColumnLayer.Series.Add(series3);
            ultraChart1.CompositeChart.Series.Add(series3);
            ultraTree1.Nodes.Add("S3", "Series 2009");
            ultraTree1.Nodes["S3"].CheckedState = CheckState.Checked;

            series4 = new NumericSeries();
            series4.DataBind(dt, "2010", "Month");
            series4.Label = "Year 2010";
            series4.PEs.Add(new PaintElement(Color.Green));
            myColumnLayer.Series.Add(series4);
            ultraChart1.CompositeChart.Series.Add(series4);
            ultraTree1.Nodes.Add("S4", "Series 2010");
            ultraTree1.Nodes["S4"].CheckedState = CheckState.Checked;

            series5 = new NumericSeries();
            series5.DataBind(dt, "2011", "Month");
            series5.Label = "Year 2011";
            series5.PEs.Add(new PaintElement(Color.Pink));
            myColumnLayer.Series.Add(series5);
            ultraChart1.CompositeChart.Series.Add(series5);
            ultraTree1.Nodes.Add("S5", "Series 2011");
            ultraTree1.Nodes["S5"].CheckedState = CheckState.Checked;

            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axis1;
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);


        }
        private void ultraTree1_AfterCheck(object sender, Infragistics.Win.UltraWinTree.NodeEventArgs e)
        {
            switch (e.TreeNode.Key)
            {
                case "S1":
                    if (e.TreeNode.CheckedState == CheckState.Checked) series1.Visible = true;
                    else series1.Visible = false;
                    break;

                case "S2":
                    if (e.TreeNode.CheckedState == CheckState.Checked) series2.Visible = true;
                    else series2.Visible = false;
                    break;

                case "S3":
                    if (e.TreeNode.CheckedState == CheckState.Checked) series3.Visible = true;
                    else series3.Visible = false;
                    break;

                case "S4":
                    if (e.TreeNode.CheckedState == CheckState.Checked) series4.Visible = true;
                    else series4.Visible = false;
                    break;

                case "S5":
                    if (e.TreeNode.CheckedState == CheckState.Checked) series5.Visible = true;
                    else series5.Visible = false;
                    break;
            }
        }

        private void ultraChart1_FillSceneGraph(object sender, FillSceneGraphEventArgs e)
        {
            List<Primitive> Addlist = new List<Primitive>();
            foreach (Primitive pr in e.SceneGraph)
            {
                if (pr.GetType() == typeof(Text) && ((Text)pr).GetTextString().Length > 0 && ((Text)pr).Row == -1 && ((Text)pr).Column == -1)
                {
                    Text tt = new Text();
                    tt.bounds = new Rectangle(((Text)pr).bounds.X, ((Text)pr).bounds.Y, ((Text)pr).bounds.Width, ((Text)pr).bounds.Height);
                    tt.SetLabelStyle(new LabelStyle(new System.Drawing.Font("Ariel",16F), Color.Black, true, false, true, StringAlignment.Center, StringAlignment.Far, TextOrientation.Horizontal));
                    tt.SetTextString(((Text)pr).GetTextString());
                    Addlist.Add(tt);
                    ((Text)pr).SetTextString("");
                }
            }
            foreach (Primitive it in Addlist) e.SceneGraph.Add(it);
        }

    }
}